﻿using System.IO;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Shapes;

namespace SilverlightKidsDoodler
{
    public class Doodle : Control
    {
        protected Canvas _content;
        protected RectangleGeometry _clip;
        protected Point? _positionLast;

        public Doodle()
        {
            // Load XAML content
            using (var resourceStream = typeof(Doodle).Assembly.GetManifestResourceStream("SilverlightKidsDoodler.Doodle.xaml"))
            {
                _content = (Canvas)InitializeFromXaml(new StreamReader(resourceStream).ReadToEnd());
            }
            _clip = (RectangleGeometry)_content.FindName("clip");
            // Initialize
            Color = Colors.Black;
            // Hook events
            MouseLeftButtonDown += new MouseEventHandler(HandleMouseLeftButtonDown);
            MouseLeftButtonUp += new MouseEventHandler(HandleMouseLeftButtonUp);
            MouseMove += new MouseEventHandler(HandleMouseMove);
        }

        private void HandleMouseLeftButtonDown(object sender, MouseEventArgs e)
        {
            // Capture mouse and update stat
            CaptureMouse();
            _positionLast = e.GetPosition(this);
        }

        private void HandleMouseLeftButtonUp(object sender, MouseEventArgs e)
        {
            // Release mouse and update stat
            ReleaseMouseCapture();
            _positionLast = null;
        }

        private void HandleMouseMove(object sender, MouseEventArgs e)
        {
            if (_positionLast.HasValue)
            {
                // Create new line
                var position = e.GetPosition(this);
                var line = new Line
                {
                    X1 = _positionLast.Value.X,
                    Y1 = _positionLast.Value.Y,
                    X2 = position.X,
                    Y2 = position.Y,
                    Stroke = new SolidColorBrush(Color),
                    StrokeThickness = 3
                };
                _content.Children.Add(line);
                // Update state
                _positionLast = position;
            }
        }

        public Color Color { get; set; }

        public void Layout(double width, double height)
        {
            // Layout control/content
            Width = width;
            Height = height;
            _content.Width = Width;
            _content.Height = Height;
            // Update clipping
            if ((0 < Width) && (0 < Height))
            {
                _clip.Rect = new Rect(0, 0, Width, Height);
            }
        }

        public void Erase()
        {
            // Clear doodle
            _content.Children.Clear();
        }
    }
}
