﻿using System;
using System.Windows.Controls;
using System.Windows.Interop;

namespace SilverlightKidsDoodler
{
    public partial class Page : Canvas
    {
        public void Page_Loaded(object o, EventArgs e)
        {
            InitializeComponent();
            // Hook events
            palette.PaletteColorSelected += new EventHandler<PaletteColorSelectedEventArgs>(HandlePaletteColorSelected);
            palette.PaletteActionSelected += new EventHandler<PaletteActionSelectedEventArgs>(HandlePaletteActionSelected);
            BrowserHost.Resize += new EventHandler(HandleResize);
            BrowserHost.FullScreenChange += new EventHandler(HandleResize);
        }

        private void HandlePaletteColorSelected(object sender, PaletteColorSelectedEventArgs e)
        {
            // Change the doodle color
            doodle.Color = e.Color;
        }

        private void HandlePaletteActionSelected(object sender, PaletteActionSelectedEventArgs e)
        {
            switch (e.PaletteAction)
            {
                case PaletteAction.Erase:
                    // Erase the doodle
                    doodle.Erase();
                    break;
                case PaletteAction.Zoom:
                    // Toggle full-screen
                    BrowserHost.IsFullScreen = !BrowserHost.IsFullScreen;
                    break;
            }
        }

        private void HandleResize(object sender, EventArgs e)
        {
            // Layout to fit new control size
            Width = BrowserHost.ActualWidth;
            Height = BrowserHost.ActualHeight;
            palette.Layout(Width, Height);
            doodle.SetValue(Canvas.LeftProperty, palette.Width);
            doodle.Layout(Width - palette.Width, Height);
        }
    }
}
