﻿using System;
using System.IO;
using System.Windows.Controls;

namespace SilverlightKidsDoodler
{
    public class Palette : Control
    {
        public event EventHandler<PaletteColorSelectedEventArgs> PaletteColorSelected;
        public event EventHandler<PaletteActionSelectedEventArgs> PaletteActionSelected;

        protected const double Border = 1;

        protected Canvas _content;

        public Palette()
        {
            // Load XAML content
            using (var resourceStream = typeof(Palette).Assembly.GetManifestResourceStream("SilverlightKidsDoodler.Palette.xaml"))
            {
                _content = (Canvas)InitializeFromXaml(new StreamReader(resourceStream).ReadToEnd());
            }
            // Hook events
            foreach(PaletteItem paletteItem in _content.Children)
            {
                var paletteColor = paletteItem as PaletteColor;
                if (null != paletteColor)
                {
                    paletteColor.PaletteColorSelected += new EventHandler<PaletteColorSelectedEventArgs>(HandlePaletteColorSelected);
                }
                var paletteButton = paletteItem as PaletteButton;
                if (null != paletteButton)
                {
                    paletteButton.PaletteActionSelected += new EventHandler<PaletteActionSelectedEventArgs>(HandlePaletteActionSelected);
                }
            }
        }

        private void HandlePaletteColorSelected(object sender, PaletteColorSelectedEventArgs e)
        {
            // Invoke corresponding event
            EventHandler<PaletteColorSelectedEventArgs> handler = PaletteColorSelected;
            if (null != handler)
            {
                handler.Invoke(this, e);
            }
        }

        private void HandlePaletteActionSelected(object sender, PaletteActionSelectedEventArgs e)
        {
            // Invoke corresponding event
            EventHandler<PaletteActionSelectedEventArgs> handler = PaletteActionSelected;
            if (null != handler)
            {
                handler.Invoke(this, e);
            }
        }

        public void Layout(double width, double height)
        {
            // Layout control/content
            Width = Math.Round((height + Border) / _content.Children.Count);
            Height = height;
            _content.Width = Width;
            _content.Height = Height;
            // Layout children items
            for(var i = 0 ; i < _content.Children.Count ; i++)
            {
                var paletteItem = (PaletteItem)_content.Children[i];
                var top = Math.Round((i * (Height + Border)) / _content.Children.Count);
                var topNext = Math.Round(((i + 1) * (Height + Border)) / _content.Children.Count);
                paletteItem.SetValue(Canvas.TopProperty, top);
                paletteItem.Layout(Width - Border, (topNext - top - Border));
            }
        }
    }
}
