﻿using System;
using System.Windows.Input;

namespace SilverlightKidsDoodler
{
    public class PaletteButton : PaletteItem
    {
        public event EventHandler<PaletteActionSelectedEventArgs> PaletteActionSelected;

        protected const int DoubleClickThreshold = 500;

        protected DateTime lastMouseLeftButtonDown = DateTime.MinValue;

        // Note: Could clip text here, but unnecessary with current design

        public string Text
        {
            get { return _textBlock.Text; }
            set
            {
                _textBlock.Text = value;
                // Don't seem to be able to put custom enums into XAML, so do corresponding work here
                if (PaletteAction.Erase.ToString() == value)
                {
                    PaletteAction = PaletteAction.Erase;
                    _content.Cursor = Cursors.Eraser;
                }
                else if (PaletteAction.Zoom.ToString() == value)
                {
                    PaletteAction = PaletteAction.Zoom;
                    _content.Cursor = Cursors.Arrow;
                }
                else
                {
                    throw new NotSupportedException("Invalid PaletteAction.");
                }
            }
        }

        public PaletteAction PaletteAction { get; protected set; }

        protected override void HandleMouseLeftButtonDown(object sender, MouseEventArgs e)
        {
            // Check for double-click when necessary
            var now = DateTime.Now;
            if ((PaletteAction.Zoom != PaletteAction) || ((now - lastMouseLeftButtonDown).TotalMilliseconds < DoubleClickThreshold))
            {
                // Fire corresponding event
                EventHandler<PaletteActionSelectedEventArgs> handler = PaletteActionSelected;
                if (null != handler)
                {
                    handler.Invoke(this, new PaletteActionSelectedEventArgs { PaletteAction = PaletteAction });
                }
            }
            // Update stote
            lastMouseLeftButtonDown = now;
        }
    }

    public class PaletteActionSelectedEventArgs : EventArgs
    {
        public PaletteAction PaletteAction { get; set; }
    }

    public enum PaletteAction { Erase, Zoom }
}
